#!/opt/anaconda1anaconda2anaconda3/bin/python
# EASY-INSTALL-SCRIPT: 'portpicker==1.3.0','portserver.py'
__requires__ = 'portpicker==1.3.0'
__import__('pkg_resources').run_script('portpicker==1.3.0', 'portserver.py')
